@@ -4,7 +4,7 @@ from rest_framework.decorators import api_view, authentication_classes, permissi
 from rest_framework.authentication import TokenAuthentication
 from rest_framework.permissions import IsAuthenticated
 from enough.api.permissions import IsEnoughGroupMember
-from enough.common import bind, hosting
+from enough.common import bind
 
 
 @api_view(['POST'])
@@ -30,19 +30,3 @@ def delegate_dns(request):
 @api_view(['GET'])
 def ping(request):
     return HttpResponse('pong')
-
-
-@api_view(['POST'])
-@authentication_classes((TokenAuthentication,))
-@permission_classes((IsAuthenticated, IsEnoughGroupMember))
-def create_or_upgrade(request):
-    return JsonResponse(hosting.Hosting(request.data['name']).create_or_upgrade(),
-                        safe=False, status=201)
-
-
-@api_view(['DELETE'])
-@authentication_classes((TokenAuthentication,))
-@permission_classes((IsAuthenticated, IsEnoughGroupMember))
-def delete(request, name):
-    return JsonResponse(hosting.Hosting(name).delete(),
-                        status=204)
