@@ -10,6 +10,10 @@ import textwrap
 log = logging.getLogger(__name__)
 
 
+class AnsibleVariableNotFound(Exception):
+    pass
+
+
 class Ansible(object):
 
     bake_method = sh.ansible
@@ -149,7 +153,7 @@ class Ansible(object):
         values = {k: v.get(variable) for k, v in out.items()}
         for k, v in values.items():
             if v == 'VARIABLE IS NOT DEFINED!':
-                raise KeyError("%r is not defined" % variable)
+                raise AnsibleVariableNotFound("%r is not defined" % variable)
         return values
 
 
