@@ -1,5 +1,5 @@
     docker run --rm \
-       -ti \
+       {{ this.tty }} \
        -v $HOME/.enough:/root/.enough \
        -v /etc/ssl/certs:/etc/ssl/certs:ro \
        -v /usr/local/share/ca-certificates:/usr/local/share/ca-certificates:ro \
