@@ -2,7 +2,7 @@ def pytest_addoption(parser):
     parser.addoption(
         "--enough-hosts",
         action="store",
-        default="bind-host,bind-client-host,external-host,icinga-host",
+        default="bind-host,bind-client-host,external-host,icinga-host,deleted-host",
         help="list of hosts"
     )
     parser.addoption(
