@@ -3,7 +3,7 @@ def pytest_addoption(parser):
         "--enough-hosts",
         action="store",
 
-        default="bind-host,runner-host,gitlab-host",
+        default="bind-host,runner-host,postfix-host,gitlab-host",
         help="list of hosts"
     )
     parser.addoption(
