@@ -1,4 +1,4 @@
-testinfra_hosts = ['ansible://icinga-host']
+testinfra_hosts = ['ansible://bind-host']
 
 
 def test_spf(host):
