@@ -149,3 +149,27 @@ def test_wazuh_syscheck(host, pytestconfig):
             sed -i -e '/email_alert_level/s/>.*</>12</' /var/ossec/etc/ossec.conf
             systemctl restart wazuh-manager
             """)
+
+
+@retry.retry(AssertionError, tries=5)
+def test_wazuh_vulnerability_detector(host):
+    with host.sudo():
+        host.file("/var/ossec/queue/vulnerabilities/cve.db").exists
+        host.file("/var/ossec/logs/ossec.log").contains('Finished vulnerability assessment')
+
+
+def test_wazuh_vulnerability_ignored(host):
+    with host.sudo():
+        host.run("""
+        systemctl stop wazuh-manager
+        rm /var/ossec/logs/alerts/alerts.log
+        rm /var/ossec/queue/vulnerabilities/cve.db
+        apt-get install -y libbsd0=0.9.1-2
+        systemctl start wazuh-manager
+        """)
+
+        @retry.retry(AssertionError, tries=8)
+        def get_alert():
+            host.file("/var/ossec/logs/alerts/alerts.log").contains('non-upgradeable packages')
+            host.file("/var/ossec/logs/alerts/alerts.log").contains('libbsd0')
+        get_alert()
