@@ -7,7 +7,8 @@ import yaml
 
 from enough import settings
 from enough.common import Enough
-from enough.common.openstack import OpenStackBase, OpenStack
+from enough.common.openstack import OpenStack
+from enough.common.ssh import SSH
 
 from tests import prepare_config_dir
 
@@ -73,7 +74,7 @@ def create_enough(tmpdir, dotenough, **kwargs):
     return enough
 
 
-def test_clone_clobber(request, tmpdir):
+def test_clone_clobber(tmpdir):
     original = create_enough(tmpdir, 'copy')
     shutil.copyfile('tests/enough/common/test_init/clone-clobber/clouds.yml',
                     f'{original.config_dir}/inventory/group_vars/all/clouds.yml')
@@ -247,7 +248,7 @@ def test_restore_remote(request, tmpdir):
 
         assert ip != clone_ip
 
-        OpenStackBase.wait_for_ssh(clone_ip, clone_port)
+        SSH.wait_for_ssh(clone_ip, clone_port)
         sh.ssh_keygen('-R', clone_ip, _ok_code=(0, 255))
         res = sh.ssh('-oStrictHostKeyChecking=no',
                      '-i', clone.dotenough.private_key(), f'-p{clone_port}',
@@ -283,7 +284,7 @@ def test_restore_local(request, tmpdir):
 
         assert e == e.restore_local(snapshot)
         assert 'sample-volume' in e.openstack.o.volume.list()
-        OpenStackBase.wait_for_ssh(ip, port)
+        SSH.wait_for_ssh(ip, port)
         sh.ssh_keygen('-R', ip, _ok_code=(0, 255))
         res = sh.ssh('-oStrictHostKeyChecking=no', '-i', e.dotenough.private_key(),
                      f'-p{port}', f'debian@{ip}', 'test', '-e', '/srv/STONE')
@@ -360,17 +361,114 @@ def test_volume_resize(request, tmpdir):
         o.destroy_everything(None)
 
 
+@pytest.mark.parametrize("service,expected", [
+    ('chat', 'chat\thttps://chat.enough.com'),
+    ('cloud', 'cloud\thttps://cloud.enough.com nextcloud_admin_user=admin'),
+    ('forum', 'forum\thttps://forum.enough.com'),
+    ('gitlab', 'gitlab\thttps://lab.enough.com user=root'),
+    ('website', 'website\thttps://www.enough.com'),
+    ('icinga', 'icinga\thttps://icinga.enough.com icingaweb2_user=icingaadmin'),
+    ('jitsi', 'jitsi\thttps://jitsi.enough.com jitsi_startAudioOnly=true'),
+    ('openedx', 'openedx\thttps://openedx.enough.com https://studio.enough.com'),
+    ('pad', 'pad\thttps://pad.enough.com user=admin'),
+    ('psono', 'psono\thttps://psono.enough.com psono_contact=admin@enough.community'),
+    ('securedrop', 'securedrop\tsecuredrop_admin_user=admin'),
+    ('wazuh', 'wazuh\twazuh_mailto=(unknown value)'),
+    ('weblate', 'weblate\thttps://weblate.enough.com user=admin'),
+    ('wekan', 'wekan\thttps://wekan.enough.com user=admin'),
+    ('wordpress', 'wordpress\thttps://wordpress.enough.com wordpress_admin_user=admin'),
+])
+def test_info_service(tmpdir, service, expected):
+    enough_domain = 'enough.com'
+    config_dir = prepare_config_dir(enough_domain, tmpdir)
+    f = f'{config_dir}/inventory/hosts.yml'
+    open(f, 'w').write(yaml.dump({
+        'all': {
+            'hosts': {
+                'some-host': {
+                    'ansible_host': '1.2.3.4',
+                }
+            }
+        }
+    }))
+    f = f'{config_dir}/inventory/services.yml'
+    open(f, 'w').write(yaml.dump({
+        f'{service}-service-group': {
+            'hosts': {
+                'some-host': None,
+            }
+        }
+    }))
+    e = Enough(config_dir, settings.SHARE_DIR,
+               domain=enough_domain,
+               driver='openstack')
+    info = e.info()
+    assert expected in info[1]
+
+
+def test_info_internal(tmpdir):
+    enough_domain = 'enough.com'
+    config_dir = prepare_config_dir(enough_domain, tmpdir)
+    f = f'{config_dir}/inventory/hosts.yml'
+    open(f, 'w').write(yaml.dump({
+        'all': {
+            'hosts': {
+                'some-host': {
+                    'ansible_host': '1.2.3.4',
+                }
+            }
+        }
+    }))
+    f = f'{config_dir}/inventory/services.yml'
+    open(f, 'w').write(yaml.dump({
+        f'bind-service-group': {
+            'hosts': {
+                'some-host': None,
+            }
+        }
+    }))
+    e = Enough(config_dir, settings.SHARE_DIR,
+               domain=enough_domain,
+               driver='openstack')
+    info = e.info()
+    assert info[1] == '\tbind\t'
+
+
+def test_info_general(tmpdir):
+    e = create_enough(tmpdir, 'info')
+    info = e.info()
+    assert info.pop(0) == 'other-host ip=10.20.30.40 port=55'
+    assert info.pop(0) == '\tbackup\t'
+    assert info.pop(0) == ('\tcloud\thttps://cloud.enough.com '
+                           'nextcloud_admin_user=admin '
+                           'enough_nextcloud_version=19 '
+                           'nextcloud_admin_pass=*****')
+    assert info.pop(0) == 'some-host ip=1.2.3.4 port=22'
+    assert info.pop(0) == ('\tcloud\thttps://cloud.enough.com '
+                           'nextcloud_admin_user=NEXTCLOUD_ADMIN_USER '
+                           'enough_nextcloud_version=ENOUGH_NEXTCLOUD_VERSION '
+                           'nextcloud_admin_pass=*****')
+    assert info.pop(0) == '\tunknown\t(unknown service)'
+
+    e.args['show_passwords'] = True
+    info = e.info()
+    assert info.pop(0) == 'other-host ip=10.20.30.40 port=55'
+    assert info.pop(0) == '\tbackup\t'
+    assert info.pop(0) == ('\tcloud\thttps://cloud.enough.com '
+                           'nextcloud_admin_user=admin '
+                           'enough_nextcloud_version=19 '
+                           'nextcloud_admin_pass=mynextcloud')
+
+
 #
 # Host
 #
 @pytest.mark.openstack_integration
-def test_host_create_or_update(request, tmpdir, openstack_name):
-    try:
-        enough = create_enough(tmpdir, 'host')
-        enough.set_args(name='new-host')
-        info = enough.host.create_or_update()
-        assert 'ipv4' in info
-    finally:
-        o = OpenStack(settings.CONFIG_DIR)
-        # comment out the following line to re-use the content of the regions and save time
-        o.destroy_everything(None)
+@pytest.mark.libvirt_integration
+def test_host_create_or_update(tmpdir, dotenough_fixture):
+    enough = Enough(dotenough_fixture.config_dir, settings.SHARE_DIR,
+                    domain=dotenough_fixture.domain,
+                    driver=dotenough_fixture.driver)
+    enough.set_args(name=dotenough_fixture.prefix)
+    info = enough.host.create_or_update()
+    assert 'ipv4' in info
