@@ -15,14 +15,17 @@ function prepare_environment() {
     if test -d ~/.ansible && test "$(find ~/.ansible ! -user $(id -u) -print -quit)" ; then
         $SUDO chown -R $(id -u) ~/.ansible
     fi
+    local d=/var/lib/libvirt/images/enough
+    if test -e /usr/sbin/libvirtd && ! test -d $d ; then
+	$SUDO mkdir -p $d
+	$SUDO chgrp libvirt $d
+	$SUDO chmod 771 $d
+    fi
 }
 
 function prepare_repository() {
     git submodule --quiet sync
     git submodule --quiet update --init --recursive
-    if test -f infrastructure_key ; then
-        chmod 600 infrastructure_key
-    fi
 }
 
 function prepare_inventory() {
@@ -72,7 +75,13 @@ function build_image() {
         if test "$GITLAB_CI" ; then
             cat tests/copy-to-opt.dockerfile
         fi
-    ) | timeout $max_execution_time docker build --build-arg=USER_ID="$(id -u)" --build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" --build-arg=USER_NAME="${USER:-root}" --tag $name -f - .
+    ) | timeout $max_execution_time docker build \
+		--build-arg=USER_ID="$(id -u)" \
+		--build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" \
+		--build-arg=LIBVIRT_GID="$(getent group libvirt | cut -d: -f3)" \
+		--build-arg=KVM_GID="$(getent group kvm | cut -d: -f3)" \
+		--build-arg=USER_NAME="${USER:-root}" \
+		--tag $name -f - .
 }
 
 function run_tests() {
@@ -87,7 +96,7 @@ function run_tests() {
     find $d \( -name '*.pyc' -o -name '*.pyo' -o -name __pycache__ \) -delete
     if test "$GITLAB_CI" ; then
         args="--workdir /opt"
-        : ${PYTEST_ADDOPTS=-m \"not openstack_integration\"}
+        : ${PYTEST_ADDOPTS=-m \"not openstack_integration and not libvirt_integration\"}
         PASS_GITLAB_CI="-e GITLAB_CI=${GITLAB_CI}"
     else
         args="--volume ${d}:${d} --workdir ${d} --volume $HOME/.enough:$HOME/.enough --volume $HOME/.ansible:$HOME/.ansible -e HOME=$HOME"
@@ -100,8 +109,27 @@ function run_tests() {
         PASS_GITLAB_CI=""
 	local interactive=-ti
     fi
+    if echo -- $@ | grep -e '--enough-driver.libvirt' ; then
+	args="$args --dns 127.0.0.1"
+    fi
+
+    if test -e /dev/kvm ; then
+	args="$args --device /dev/kvm"
+    fi
+
     container_name="$name-$(date +%s)"
-    docker run $interactive --rm --device=/dev/net/tun --name $container_name --user "${USER:-root}" -e PYTEST_ADDOPTS="${PYTEST_ADDOPTS-}" -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN ${PASS_GITLAB_CI} --cap-add=NET_ADMIN $args --volume /var/run/docker.sock:/var/run/docker.sock $name "${@:-tox}"
+    docker run $interactive --rm \
+	   --name $container_name \
+	   --user "${USER:-root}" \
+	   -e PYTEST_ADDOPTS="${PYTEST_ADDOPTS-}" \
+	   -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN ${PASS_GITLAB_CI} \
+	   --cap-add=NET_ADMIN \
+	   --device=/dev/net/tun \
+	   $args \
+	   --volume /run/libvirt/libvirt-sock:/run/libvirt/libvirt-sock \
+	   --volume /var/run/docker.sock:/var/run/docker.sock \
+	   --volume /var/lib/libvirt/images/enough:/var/lib/libvirt/images/enough \
+	   $name "${@:-tox}"
 }
 
 function main() {
